==> sale-3.5.3.jar: revenue/sqls/FileManage/nc/ncarchivesQuery.sql <==
select * from (
  SELECT
    tc.*,
    tc.f_customer f_userinfo_code,
    isnull(uf.num, 0) sumuserfiles,
    isnull(h.f_oughtfee_all, 0) f_oughtfee_all
  FROM t_civill tc left join (
    select count(*) num,f_civill_id from (
      select f_userinfo_id,f_civill_id from t_userfiles where f_civill_id is not null group by f_civill_id,f_userinfo_id
    ) u GROUP BY f_civill_id
  ) uf on tc.id = uf.f_civill_id
  left join (
    select * from (
                      select
                          f_civill_id,
                          sum(f_oughtfee)  f_oughtfee_all --合计欠费金额
                      from (
                               SELECT
                                   f_civill_id,
                                   handplan_id,                                            --抄表记录id
                                   ROUND(f_oughtfee-f_debt_money,2) f_oughtfee,            --实际应交金额 convert(decimal(18,2),f_oughtfee-f_debt_money) ROUND(f_oughtfee-f_debt_money,2)
                                   f_debt_money    --已交气费 convert(decimal(18,2),f_debt_money) ROUND(f_debt_money,2)
                               FROM(
                                       SELECT
                                           h.id as handplan_id,
                                           h.f_oughtfee,
                                           isnull(f_debt_money,0) f_debt_money,
                                           uf.f_civill_id
                                       FROM t_handplan h
                                       LEFT JOIN (
                                           SELECT
                                               f_hand_id,SUM(f_debt_money) f_debt_money
                                           FROM t_sellinghand d
                                           WHERE f_state = '有效'
                                           GROUP BY f_hand_id
                                       ) sh on h.id = sh.f_hand_id
                                       --LEFT JOIN t_userinfo u ON h.f_userinfo_id = u.f_userinfo_id
                                       left join t_userfiles uf on h.f_userfiles_id = uf.f_userfiles_id
                                       WHERE
                                               f_whether_pay='否' AND f_hand_state = '有效' and
                                               h.f_meter_state = '已抄表' AND f_oughtfee>0
                                   ) p
                           ) h
                      group by f_civill_id
    ) h
  ) h on tc.id = h.f_civill_id
) tc WHERE { condition }
ORDER BY
	tc.id DESC

==> sale-3.7.1.jar: revenue/sqls/FileManage/nc/ncarchivesQuery.sql <==
select * from (
  SELECT
    tc.*,
    tc.f_customer f_userinfo_code,
    isnull(uf.num, 0) sumuserfiles,
    isnull(h.f_oughtfee_all, 0) f_oughtfee_all
  FROM t_civill tc left join (
    select count(*) num,f_civill_id from (
      select f_userinfo_id,f_civill_id from t_userfiles where f_civill_id is not null group by f_civill_id,f_userinfo_id
    ) u GROUP BY f_civill_id
  ) uf on tc.id = uf.f_civill_id
  left join (
    select * from (
                      select
                          f_civill_id,
                          sum(f_oughtfee)  f_oughtfee_all --合计欠费金额
                      from (
                               SELECT
                                   f_civill_id,
                                   handplan_id,                                            --抄表记录id
                                   ROUND(f_oughtfee-f_debt_money,2) f_oughtfee,            --实际应交金额 convert(decimal(18,2),f_oughtfee-f_debt_money) ROUND(f_oughtfee-f_debt_money,2)
                                   f_debt_money    --已交气费 convert(decimal(18,2),f_debt_money) ROUND(f_debt_money,2)
                               FROM(
                                       SELECT
                                           h.id as handplan_id,
                                           h.f_oughtfee,
                                           isnull(f_debt_money,0) f_debt_money,
                                           uf.f_civill_id
                                       FROM t_handplan h with(nolock)
                                       LEFT JOIN (
                                           SELECT
                                               f_hand_id,SUM(f_debt_money) f_debt_money
                                           FROM t_sellinghand d  with(nolock)
                                           WHERE f_state = '有效'
                                           GROUP BY f_hand_id
                                       ) sh on h.id = sh.f_hand_id
                                       --LEFT JOIN t_userinfo u ON h.f_userinfo_id = u.f_userinfo_id
                                       left join t_userfiles uf on h.f_userfiles_id = uf.f_userfiles_id
                                       WHERE
                                               f_whether_pay='否' AND f_hand_state = '有效' and
                                               h.f_meter_state = '已抄表' AND f_oughtfee>0
                                   ) p
                           ) h
                      group by f_civill_id
    ) h
  ) h on tc.id = h.f_civill_id
) tc WHERE { condition }
ORDER BY
	tc.id DESC
